# ChangeTip Python Library
A set of tools for interacting with the [ChangeTip](https://www.changetip.com) API.

## Install

`pip install changetip`

## Examples
TODO

## Tests
`python setup.py test`

## License
MIT
